@@ -1,4 +1,4 @@
-from features_infra.feature_calculators import NodeFeatureCalculator, FeatureMeta
+from ...features_infra.feature_calculators import NodeFeatureCalculator, FeatureMeta
 
 
 class GeneralCalculator(NodeFeatureCalculator):
@@ -19,5 +19,5 @@ feature_entry = {
 
 
 if __name__ == "__main__":
-    from measure_tests.specific_feature_test import test_specific_feature
+    from ...measure_tests.specific_feature_test import test_specific_feature
     test_specific_feature(GeneralCalculator, is_max_connected=True)
