@@ -1,7 +1,7 @@
 import networkx as nx
 import numpy as np
 
-from features_infra.feature_calculators import NodeFeatureCalculator, FeatureMeta
+from ...features_infra.feature_calculators import NodeFeatureCalculator, FeatureMeta
 
 
 class GeneralizedDegreeCalculator(NodeFeatureCalculator):
@@ -27,5 +27,5 @@ feature_entry = {
 
 
 if __name__ == "__main__":
-    from measure_tests.specific_feature_test import test_specific_feature
+    from ...measure_tests.specific_feature_test import test_specific_feature
     test_specific_feature(GeneralizedDegreeCalculator, is_max_connected=True)
\ No newline at end of file
